/* Copyright (C) 1996,1997,1998,1999,2002,2003 Free Software Foundation, Inc.
   This file is part of the GNU C Library.

   The GNU C Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   The GNU C Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with the GNU C Library; if not, see
   <http://www.gnu.org/licenses/>.  */

/* This file is included multiple times.  */

#include_next <siglist.h>	/* Get the canonical list.  */

#define	OLD_SIGLIST_SIZE	32 /* For GLIBC_2.0 binary compatibility.  */

#define OLD2_SIGLIST_SIZE	64 /* For GLIBC_2.1 binary compatibility.  */
